@@ -1,5 +1,6 @@
 __all__ = [
-  'StatusCode'
+  'StatusCode',
+  'StatusTrigger'
 ]
 
 class StatusObject ():
@@ -24,4 +25,11 @@ class StatusCode ():
   """
   SUCCESS = StatusObject(0)
   FAILURE = StatusObject(-1)
-  FATAL   = StatusObject(-2)
\ No newline at end of file
+  FATAL   = StatusObject(-2)
+
+class StatusTrigger ():
+  """
+  Status code for Trigger objects
+  """
+  NOT_TRIGGERED   = False
+  TRIGGERED       = True
